@@ -31,7 +31,7 @@ our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 
 our @EXPORT = qw();
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -168,7 +168,7 @@ L<sendfile(2)>
 
 =head1 AUTHOR
 
-Dave Lambley, E<lt>dlambley@cpan.org<gt>
+Dave Lambley, E<lt>dlambley@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
